@@ -4,8 +4,11 @@ from numpy.linalg import norm
 import abc
 
 from highrl.obstacle.single_obstacle import SingleObstacle
-from highrl.utils.calculations import point_to_obstacle_distance
 from highrl.utils.action import ActionXY
+from highrl.utils.calculations import (
+    point_to_obstacle_distance,
+    point_to_point_distance,
+)
 
 
 class Agent(object):
@@ -22,8 +25,6 @@ class Agent(object):
         theta=0,
         radius=20,
         goal_radius=10,
-        config=None,
-        section=None,
     ):
         """
         Base class for robot and human. Have the physical attributes of an agent.
@@ -86,13 +87,6 @@ class Agent(object):
         self.vy = velocity[1]
         self.w = velocity[2]
 
-    @abc.abstractmethod
-    def act(self, ob):
-        """
-        Compute state using received observation and pass it to policy
-        """
-        return
-
     def check_validity(self, action):
         assert isinstance(action, ActionXY)
 
@@ -130,45 +124,84 @@ class Agent(object):
             np.array(self.get_position()) - np.array(self.get_goal_position())  # type: ignore
         ) < (self.radius + self.goal_radius)
 
-    def is_overlapped(self, obstacle: SingleObstacle):
-        """Check if there is no overlap between the robot and an obstacle
+    def is_overlapped(self, obstacle: SingleObstacle, check_target: str = "robot"):
+        """Check if there is no overlap between either the robot or the goal and an obstacle
 
         Args:
             obstacle (SingleObstacle): input obstalce
+            check_target (str): target to be checked, either robot or goal
 
         Returns:
             bool: flag to determine if there is no overlap
         """
-        # min_x, min_y, max_x, max_y
-        dummy1 = [
+        assert check_target in [
+            "goal",
+            "robot",
+        ], f"check target should be goal or robot"
+        if check_target == "goal":
+            min_x = self.gx - self.goal_radius
+            min_y = self.gy - self.goal_radius
+            max_x = self.gx + self.goal_radius
+            max_y = self.gy + self.goal_radius
+        else:
+            min_x = self.px - self.radius
+            min_y = self.py - self.radius
+            max_x = self.px + self.radius
+            max_y = self.py + self.radius
+
+        dummy = [
+            [
+                min_x,
+                min_y,
+                max_x,
+                max_y,
+            ],
+            [
+                obstacle.px,
+                obstacle.py,
+                obstacle.px + obstacle.width,
+                obstacle.py + obstacle.height,
+            ],
+        ]
+        return not (self._overlap_handler(dummy))
+
+    def is_robot_overlap_goal(self):
+        """Check if the robot and goal are overlapping
+
+        Returns:
+            bool: flag to determine if there is overlap
+        """
+        dummy = [
+            [
+                self.gx - self.goal_radius,
+                self.gy - self.goal_radius,
+                self.gx + self.goal_radius,
+                self.gy + self.goal_radius,
+            ],
             [
                 self.px - self.radius,
                 self.py - self.radius,
                 self.px + self.radius,
                 self.py + self.radius,
             ],
-            [
-                obstacle.px,
-                obstacle.py,
-                obstacle.px + obstacle.width,
-                obstacle.py + obstacle.height,
-            ],
         ]
-        dummy2 = [
-            [
-                self.gx - self.radius,
-                self.gy - self.radius,
-                self.gx + self.radius,
-                self.gy + self.radius,
-            ],
-            [
-                obstacle.px,
-                obstacle.py,
-                obstacle.px + obstacle.width,
-                obstacle.py + obstacle.height,
-            ],
-        ]
-        return not (self._overlap_handler(dummy1) and self._overlap_handler(dummy2))
+        return not (self._overlap_handler(dummy))
+
+    def is_robot_close_to_goal(self, min_dist: int):
+        """Check to see if the robot is too close to the goal
+
+        Args:
+            max_dist (int): The max allowable distance that the robot can be to the goal at the start of the session
+
+        Returns:
+            bool: flag to determine if the robot is too close
+        """
+        distance = point_to_point_distance((self.px, self.py), (self.gx, self.gy)) - (
+            self.radius + self.goal_radius
+        )
+        if distance <= min_dist:
+            return True
+        return False
 
     def _overlap_handler(self, dummy):
         """Check overlap condition between two objects
@@ -183,5 +216,4 @@ class Agent(object):
             if dummy[0][0] > dummy[1][2] or dummy[0][1] > dummy[1][3]:
                 return True
             dummy[0], dummy[1] = dummy[1], dummy[0]
-
         return False
